@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 import re
 import autoslug
 import pytz
@@ -6,7 +9,7 @@ from django.db import models
 from django.db.models import lookups
 from django.utils.encoding import force_str
 from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 from unidecode import unidecode
 
