@@ -1,5 +1,7 @@
 """Data downloader."""
 
+from __future__ import unicode_literals
+
 import logging
 import time
 import os
@@ -11,7 +13,7 @@ from urllib.parse import urlparse
 from .exceptions import SourceFileDoesNotExist
 
 
-class Downloader:
+class Downloader(object):
 
     """Geonames data downloader class."""
 
